from setuptools import setup, find_packages

setup(
    name='Lgk',
    version='1.2',
    packages=['Lgk'],
    description='Description: just write Lgk.Help()',
    author='BT Ansixs',
    author_email='noobra24l8w@gmail.com',
    license='LICENSE',
)
